==> okta-sdk-api-20.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/UserSchemaAttributeEnum.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * UserSchemaAttributeEnum
 */
@JsonPropertyOrder({ UserSchemaAttributeEnum.JSON_PROPERTY_CONST, UserSchemaAttributeEnum.JSON_PROPERTY_TITLE })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class UserSchemaAttributeEnum implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_CONST = "const";
    private String _const;

    public static final String JSON_PROPERTY_TITLE = "title";
    private String title;

    public UserSchemaAttributeEnum() {
    }

    public UserSchemaAttributeEnum _const(String _const) {

        this._const = _const;
        return this;
    }

    /**
     * Get _const
     *
     * @return _const
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CONST)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getConst() {
        return _const;
    }

    @JsonProperty(JSON_PROPERTY_CONST)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setConst(String _const) {
        this._const = _const;
    }

    public UserSchemaAttributeEnum title(String title) {

        this.title = title;
        return this;
    }

    /**
     * Get title
     *
     * @return title
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_TITLE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getTitle() {
        return title;
    }

    @JsonProperty(JSON_PROPERTY_TITLE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setTitle(String title) {
        this.title = title;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UserSchemaAttributeEnum userSchemaAttributeEnum = (UserSchemaAttributeEnum) o;
        return Objects.equals(this._const, userSchemaAttributeEnum._const)
                && Objects.equals(this.title, userSchemaAttributeEnum.title);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(_const, title);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class UserSchemaAttributeEnum {\n");
        sb.append("    _const: ").append(toIndentedString(_const)).append("\n");
        sb.append("    title: ").append(toIndentedString(title)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-24.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/UserSchemaAttributeEnum.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * UserSchemaAttributeEnum
 */
@JsonPropertyOrder({ UserSchemaAttributeEnum.JSON_PROPERTY_CONST, UserSchemaAttributeEnum.JSON_PROPERTY_TITLE })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-07-28T10:14:57.946459+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class UserSchemaAttributeEnum implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_CONST = "const";
    private String _const;

    public static final String JSON_PROPERTY_TITLE = "title";
    private String title;

    public UserSchemaAttributeEnum() {
    }

    public UserSchemaAttributeEnum _const(String _const) {

        this._const = _const;
        return this;
    }

    /**
     * Get _const
     *
     * @return _const
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CONST)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getConst() {
        return _const;
    }

    @JsonProperty(JSON_PROPERTY_CONST)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setConst(String _const) {
        this._const = _const;
    }

    public UserSchemaAttributeEnum title(String title) {

        this.title = title;
        return this;
    }

    /**
     * Get title
     *
     * @return title
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_TITLE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getTitle() {
        return title;
    }

    @JsonProperty(JSON_PROPERTY_TITLE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setTitle(String title) {
        this.title = title;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UserSchemaAttributeEnum userSchemaAttributeEnum = (UserSchemaAttributeEnum) o;
        return Objects.equals(this._const, userSchemaAttributeEnum._const)
                && Objects.equals(this.title, userSchemaAttributeEnum.title);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(_const, title);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class UserSchemaAttributeEnum {\n");
        sb.append("    _const: ").append(toIndentedString(_const)).append("\n");
        sb.append("    title: ").append(toIndentedString(title)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
